cgexplore.terms.FoundAngle
==========================

.. currentmodule:: cgexplore.terms

.. autoclass:: FoundAngle
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~FoundAngle.atoms
      ~FoundAngle.atom_ids
   
   